@@ -19,7 +19,7 @@ our @ISA = qw( Inline::C );    ## no critic (ISA)
 # Development releases will have a _0xx version suffix.
 # We eval the version number to accommodate dev. version numbering, as
 # described in perldoc perlmodstyle.
-our $VERSION = '0.61';
+our $VERSION = '0.62';
 # $VERSION = eval $VERSION; ## no critic (eval)
 
 my $TYPEMAP_KIND;
@@ -334,11 +334,8 @@ sub xs_bindings {
       elsif ($ref_classes_override eq 'CODE')
       {
         # Override both package and class names
-        (my $class_auto, my $pkg_auto)
-          = &{$o->{API}{classes_override}}($class);
-        if   ($pkg_auto eq '') { $pkg = 'main'; }
-        else                   { $pkg = $pkg_auto; }
-        $proper_pkg = $pkg . '::' . $class_auto;
+        $proper_pkg = &{$o->{API}{classes_override}}($class);
+        if   ($proper_pkg eq '') { $proper_pkg = 'main'; }
       }
     }
     else {        # Do not override package or class names
